@@ -53,7 +53,7 @@
 /* This forces the GType to be registered in a way that
  * avoids a "statement with no effect" compiler warning.
  * FIXME Use g_type_ensure() once we require GLib 2.34. */
-#define REGISTER_TYPE(type) \
+#define REGISTER_TYPE(type)	  \
 	(g_type_class_unref (g_type_class_ref (type)))
 
 /*----------------------------------------------------------------------------*/
@@ -172,6 +172,12 @@ book_backend_kolab_signal_online_cb (GObject *object)
 	 *
 	 */
 
+	if (priv->book_koma == NULL) {
+		g_warning ("%s()[%u] Backend not been opened, ignoring online state request",
+		           __func__, __LINE__);
+		return;
+	}
+
 	(void) kolab_util_backend_deploy_mode_by_backend (priv->book_koma,
 	                                                  online,
 	                                                  NULL, /* GCancellable (see above) */
@@ -240,16 +246,12 @@ book_backend_kolab_open (EBookBackendSync *backend,
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
-	ESource *esource = NULL;
-	ESourceKolabFolder *extension = NULL;
 	CamelKolabIMAPXSettings *kolab_settings = NULL;
 	CamelNetworkSettings *network_settings = NULL;
 	KolabSettingsHandler *ksettings = NULL;
-	KolabSyncStrategyID sync_value = KOLAB_SYNC_STRATEGY_DEFAULT;
-	const gchar *extension_name = NULL;
-	const gchar *foldername = NULL;
 	gchar *servername = NULL;
 	gchar *username = NULL;
+	const gchar *user_home = NULL;
 	gboolean online = FALSE;
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
@@ -263,13 +265,6 @@ book_backend_kolab_open (EBookBackendSync *backend,
 	self = E_BOOK_BACKEND_KOLAB (backend);
 	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
 
-	esource = e_backend_get_source (E_BACKEND (backend));
-	if (! E_IS_SOURCE (esource)) {
-		tmp_err = e_data_book_create_error (E_DATA_BOOK_STATUS_OTHER_ERROR,
-		                                    _("Could not get ESource for backend"));
-		goto exit;
-	}
-
 	kolab_settings = book_backend_kolab_get_collection_settings (self);
 	network_settings = CAMEL_NETWORK_SETTINGS (kolab_settings);
 
@@ -278,17 +273,11 @@ book_backend_kolab_open (EBookBackendSync *backend,
 	g_debug ("%s()[%u] servername = %s", __func__, __LINE__, servername);
 	g_debug ("%s()[%u]   username = %s", __func__, __LINE__, username);
 
-	/* Prepare data from sync strategy property */
-	extension_name = E_SOURCE_EXTENSION_KOLAB_FOLDER;
-	extension = e_source_get_extension (esource, extension_name);
-	sync_value = e_source_kolab_folder_get_sync_strategy (extension);
-	
 	online = e_backend_get_online (E_BACKEND (backend));
-	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	/* init subsystems (these are no-ops if already called before) */
 	kolab_util_glib_init ();
-	kolab_util_http_init ();
+
 	/* libcamel
 	 * Curl init may configure the underlying SSL lib,
 	 * but as far as SSL goes, we want Camel to rule here
@@ -299,7 +288,8 @@ book_backend_kolab_open (EBookBackendSync *backend,
 		goto exit;
 
 	/* Configure settings handler */
-	ksettings = kolab_settings_handler_new (kolab_settings);
+	ksettings = kolab_settings_handler_new (kolab_settings,
+	                                        E_BACKEND (backend));
 	ok = kolab_settings_handler_configure (ksettings,
 	                                       KOLAB_FOLDER_CONTEXT_CONTACT,
 	                                       &tmp_err);
@@ -310,18 +300,19 @@ book_backend_kolab_open (EBookBackendSync *backend,
 	if (! ok)
 		goto exit;
 
-	kolab_util_backend_prepare_settings (ksettings,
-	                                     esource,
-	                                     NULL,
-	                                     foldername,
-	                                     &sync_value);
+	/* init the HTTP utils */
+	user_home = kolab_settings_handler_get_char_field (ksettings,
+	                                                   KOLAB_SETTINGS_HANDLER_CHAR_FIELD_USER_HOME_DIR,
+	                                                   &tmp_err);
+	if (tmp_err != NULL)
+		goto exit;
+	kolab_util_http_init (user_home);
 
 	/* create new KolabMailAccess instance */
 	priv->book_koma = KOLAB_MAIL_ACCESS (g_object_new (KOLAB_TYPE_MAIL_ACCESS, NULL));
 
 	/* configure and bring up KolabMailAccess instance */
 	ok = kolab_mail_access_configure (priv->book_koma,
-	                                  E_BACKEND (backend),
 	                                  ksettings,
 	                                  &tmp_err);
 	if (! ok)
@@ -956,6 +947,12 @@ book_backend_kolab_start_book_view (EBookBackend *backend,
 
 	g_object_ref (book_view); /* unref()d in stop_view() */
 
+	if (priv->book_koma == NULL) {
+		g_warning ("%s()[%u] Backend not been opened, not updating view",
+		           __func__, __LINE__);
+		goto exit;
+	}
+
 	query = e_data_book_view_get_card_query (book_view);
 	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
