@@ -876,6 +876,7 @@ e_kolab_folder_permissions_ui_new (void)
 
 	/* documenting initial settings */
 	uidata->shell_view = NULL;
+	uidata->shell_context = KOLAB_FOLDER_CONTEXT_INVAL;
 	uidata->alert_bar = NULL;
 	uidata->dialog = NULL;
 	uidata->foldername = NULL;
@@ -1031,6 +1032,9 @@ e_kolab_folder_permissions_ui_query_store (KolabFolderPermUIData *uidata,
 	g_return_val_if_fail (uidata->permissions != NULL, FALSE);
 	g_return_val_if_fail (uidata->permissions->acl == NULL, FALSE);
 
+	if (uidata->shell_context != KOLAB_FOLDER_CONTEXT_EMAIL)
+		goto exit; /* ACL can be done from email view only */
+
 	/* If we cannot get the store here, it means
 	 * that the store associated with the selected
 	 * path is not a CamelKolabIMAPXStore. This
@@ -1085,7 +1089,7 @@ e_kolab_folder_permissions_ui_write_store (KolabFolderPermUIData *uidata,
 	CamelKolabIMAPXStore *kstore = NULL;
 	gchar *selected_path = NULL;
 	GError *tmp_err = NULL;
-	gboolean ok = FALSE;
+	gboolean ok = TRUE;
 
 	g_return_val_if_fail (uidata != NULL, FALSE);
 	/* cancellable may be NULL */
@@ -1094,6 +1098,9 @@ e_kolab_folder_permissions_ui_write_store (KolabFolderPermUIData *uidata,
 	g_return_val_if_fail (E_IS_SHELL_VIEW (uidata->shell_view), FALSE);
 	g_return_val_if_fail (uidata->permissions != NULL, FALSE);
 
+	if (uidata->shell_context != KOLAB_FOLDER_CONTEXT_EMAIL)
+		goto exit; /* ACL can be done from email view only */
+
 	if (! uidata->changed)
 		return TRUE;
 
