@@ -312,6 +312,68 @@ kolab_session_authenticate_sync (CamelSession *session,
 	return authenticated;
 }
 
+static gint
+kolab_session_alert_user (CamelSession *session,
+                          CamelSessionAlertType type,
+                          const gchar *prompt,
+                          GSList *button_captions)
+{
+	gint rval = -1;
+
+	g_return_val_if_fail (CAMEL_IS_SESSION (session), -1);
+	/* prompt may be NULL */
+	(void) button_captions;
+
+	/* should we even pop up a dialog from within E-D-S? */
+	if (prompt != NULL) {
+		g_warning ("%s()[%u] (%u) \n%s",
+		           __func__, __LINE__, type, prompt);
+	}
+
+	/* XXX SSL certificate workaround
+	 *
+	 * When seeing a new server certificate for the first time,
+	 * which it cannot automatically validate by chaining-up the CA,
+	 * CamelTCPStreamSSL::ssl_bad_cert() will invoke this function
+	 * to query the user whether the certificate should or should not
+	 * be accepted. In the evolution-kolab plugin, the collection
+	 * backend will be the first one to arrive here, then the cal/book
+	 * backends, each in separate processes. Last, Evo itself will
+	 * arrive in its own CamelSession implementation's alert_user(),
+	 * which displays the accept/decline dialog. Current implementation
+	 * of CamelTCPStreamSSL::ssl_bad_cert() does the following, based
+	 * on the return value of this function:
+	 *
+	 * 0: reject the cert in question
+	 * 1: temporarily accept the cert in question
+	 * 2: permanently accept the cert in question
+	 *
+	 * all else is regarded "fail and ask again"
+	 *
+	 * The best we can do here at the moment is to temporarily accept
+	 * the server cert in backend (collection/calendar/contacts)
+	 * context, since the certificate is *always* written into the
+	 * Camel cert_db by CamelTCPStreamSSL::ssl_bad_cert(), only the
+	 * trust level is set according to the user selection in alert_user().
+	 * That means we need to act here and cannot just fail to let Evo
+	 * handle everything. If we temporarily accept, Evolution will still
+	 * ask for certificate accept/decline, and the result will be written
+	 * to the cert_db, from where the trust level selection is picked
+	 * up on next E-D-S restart
+	 */
+
+	if (g_slist_length (button_captions) == 3)
+		/* this is some guessing about whether
+		 * we're asked for server cert accept/decline
+		 * (cannot parse button captions or prompt,
+		 * since these will be translated, but bad_cert()
+		 * is the only instance calling us - good luck!)
+		 */
+		rval = 1; /* temporarily accept, Evo will ask for confirmation */
+
+	return rval;
+}
+
 /*----------------------------------------------------------------------------*/
 /* class init */
 
@@ -330,6 +392,7 @@ camel_kolab_session_class_init (CamelKolabSessionClass *klass)
 	object_class->finalize = camel_kolab_session_finalize;
 
 	session_class->add_service = parent_class->add_service;
+	session_class->alert_user = kolab_session_alert_user;
 	session_class->authenticate_sync = kolab_session_authenticate_sync;
 
 	g_object_class_install_property (
