@@ -35,12 +35,15 @@
 
 #include <libekolabutil/kolab-util-folder.h>
 
+#include "kolab-types.h"
+
 /*----------------------------------------------------------------------------*/
 
 typedef struct _KolabDataFolderMetadata KolabDataFolderMetadata;
 struct _KolabDataFolderMetadata {
 	gchar *foldername;
 	KolabFolderTypeID foldertype;
+	KolabSyncStrategyID strategy;
 	gboolean show_all; /* whether to unhide PIM folders */
 };
 
