@@ -35,40 +35,11 @@
  *
  * This class is handles all Kolab (account) settings for the
  * Kolab backends. This means (mostly) reading the settings information created by
- * the Evolution frontend and encapsulating operations concerning #EAccount and
+ * the Evolution frontend and encapsulating operations concerning
  * #ESource classes. One instance of this class will live in each backend
  * process and is passed to #KolabMailAccess (and by #KolabMailAccess, on to
  * all of it's subordinate objects).
  *
- * Some of the MAPI ExchangeMAPIAccountListener functionality will be
- * replicated, which is
- * <itemizedlist>
- *   <listitem>checking for new Kolab2 account types showing up (EAccount)</listitem>
- *   <listitem>creating an associated ESource object and add it to the
- *             backend's ESourceGroup, so it can be advertised to the frontend</listitem>
- * </itemizedlist>
- *
- * In MAPI, #ExchangeMAPIAccountListener is part of the MAPI #EPlugin. According
- * to mbarnes, the account listener's functionality should be working in
- * backend context as well, so no need to place this into an #EPlugin (what's
- * more, again according to mbarnes, #EPlugin is going to be replaced entirely
- * by another framework, presumably #GTypeModule, so no point in creating an
- * elaborated #EPlugin now, anyway).
- *
- * This account listener could peek (new) #EAccount for (new) Kolab2 ones
- * and create #ESourceGroup elements accordingly. Since a backend process needs
- * to be started only when at least one Kolab2 #EAccount is configured, this
- * functionality might best be placed into the book/cal factory processes.
- *
- * Account management for future Evo versions is under reconstruction in present
- * dev versions (2010-12-21). GConf is being replaced by GSettings, and a new
- * notification framework is being brought up (see evolution-hackers list,
- * "Rethinking account management" threads by mbarnes et al, 2010-10/2010-11),
- * especially http://mail.gnome.org/archives/evolution-hackers/2010-December/msg00030.html
- *
- * This class encapsulates as much of the API changes between 2.3x and 3.x
- * as possible so the GConf->GSettings transition changes can be confined to
- * this class.
  */
 
 /*----------------------------------------------------------------------------*/
@@ -91,6 +62,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include <libebackend/libebackend.h>
+
 #include <libekolabutil/kolab-util-folder.h>
 #include <libekolab/camel-kolab-imapx-settings.h>
 
@@ -125,6 +98,7 @@ typedef enum {
 	KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CACHE_DIR,
 	KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR,
 	KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_ACCOUNT_DIR,
+	KOLAB_SETTINGS_HANDLER_CHAR_FIELD_USER_HOME_DIR,
 	KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID,
 	KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD,
 	KOLAB_SETTINGS_HANDLER_CHAR_LAST_FIELD
@@ -132,6 +106,7 @@ typedef enum {
 
 typedef enum {
 	KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT = 0,
+	KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_SYNCSTRATEGY,
 	KOLAB_SETTINGS_HANDLER_UINT_LAST_FIELD
 } KolabSettingsHandlerUintFieldID;
 
@@ -150,36 +125,74 @@ typedef enum {
 	KOLAB_SETTINGS_HANDLER_BOOL_LAST_FIELD
 } KolabSettingsHandlerBoolFieldID;
 
-typedef enum {
-	KOLAB_SETTINGS_HANDLER_TBL_SYNCSTRATEGY = 0, /* sourcename:KolabSyncStrategyID */
-	KOLAB_SETTINGS_HANDLER_TBL_FOLDERCREATE,     /* sourcename:bool (whether to create folder if not existing) */
-	KOLAB_SETTINGS_HANDLER_LAST_TBL
-} KolabSettingsHandlerTblID;
-
 GType kolab_settings_handler_get_type (void) G_GNUC_CONST;
 
-KolabSettingsHandler * kolab_settings_handler_new (CamelKolabIMAPXSettings *camel_settings);
+KolabSettingsHandler*
+kolab_settings_handler_new (CamelKolabIMAPXSettings *camel_settings,
+                            EBackend *e_backend);
 
-gboolean kolab_settings_handler_configure (KolabSettingsHandler *self, KolabFolderContextID context, GError **err);
-gboolean kolab_settings_handler_bringup (KolabSettingsHandler *self, GError **err);
-gboolean kolab_settings_handler_shutdown (KolabSettingsHandler *self, GError **err);
+gboolean
+kolab_settings_handler_configure (KolabSettingsHandler *self,
+                                  KolabFolderContextID context,
+                                  GError **err);
 
-CamelKolabIMAPXSettings * kolab_settings_handler_get_camel_settings (KolabSettingsHandler *self);
+gboolean
+kolab_settings_handler_bringup (KolabSettingsHandler *self,
+                                GError **err);
 
-gboolean kolab_settings_handler_set_char_field (KolabSettingsHandler *self, KolabSettingsHandlerCharFieldID field_id, gchar *value, GError **err);
-const gchar* kolab_settings_handler_get_char_field (KolabSettingsHandler *self, KolabSettingsHandlerCharFieldID field_id, GError **err);
+gboolean
+kolab_settings_handler_shutdown (KolabSettingsHandler *self,
+                                 GError **err);
 
-gboolean kolab_settings_handler_set_uint_field (KolabSettingsHandler *self, KolabSettingsHandlerUintFieldID field_id, guint value, GError **err);
-guint kolab_settings_handler_get_uint_field (KolabSettingsHandler *self, KolabSettingsHandlerUintFieldID field_id, GError **err);
+CamelKolabIMAPXSettings*
+kolab_settings_handler_get_camel_settings (KolabSettingsHandler *self);
 
-gboolean kolab_settings_handler_set_int_field (KolabSettingsHandler *self, KolabSettingsHandlerIntFieldID field_id, gint value, GError **err);
-gint kolab_settings_handler_get_int_field (KolabSettingsHandler *self, KolabSettingsHandlerIntFieldID field_id, GError **err);
+EBackend*
+kolab_settings_handler_get_e_backend (KolabSettingsHandler *self);
 
-gboolean kolab_settings_handler_set_bool_field (KolabSettingsHandler *self, KolabSettingsHandlerBoolFieldID field_id, gboolean value, GError **err);
-gboolean kolab_settings_handler_get_bool_field (KolabSettingsHandler *self, KolabSettingsHandlerBoolFieldID field_id, GError **err);
+gboolean
+kolab_settings_handler_set_char_field (KolabSettingsHandler *self,
+                                       KolabSettingsHandlerCharFieldID field_id,
+                                       gchar *value,
+                                       GError **err);
 
-gboolean kolab_settings_handler_set_value (KolabSettingsHandler *self, KolabSettingsHandlerTblID tbl_id, const gchar *key, gpointer value, GError **err);
-gconstpointer kolab_settings_handler_get_value (KolabSettingsHandler *self, KolabSettingsHandlerTblID tbl_id, const gchar *key, GError **err);
+const gchar*
+kolab_settings_handler_get_char_field (KolabSettingsHandler *self,
+                                       KolabSettingsHandlerCharFieldID field_id,
+                                       GError **err);
+
+gboolean
+kolab_settings_handler_set_uint_field (KolabSettingsHandler *self,
+                                       KolabSettingsHandlerUintFieldID field_id,
+                                       guint value,
+                                       GError **err);
+
+guint
+kolab_settings_handler_get_uint_field (KolabSettingsHandler *self,
+                                       KolabSettingsHandlerUintFieldID field_id,
+                                       GError **err);
+
+gboolean
+kolab_settings_handler_set_int_field (KolabSettingsHandler *self,
+                                      KolabSettingsHandlerIntFieldID field_id,
+                                      gint value,
+                                      GError **err);
+
+gint
+kolab_settings_handler_get_int_field (KolabSettingsHandler *self,
+                                      KolabSettingsHandlerIntFieldID field_id,
+                                      GError **err);
+
+gboolean
+kolab_settings_handler_set_bool_field (KolabSettingsHandler *self,
+                                       KolabSettingsHandlerBoolFieldID field_id,
+                                       gboolean value,
+                                       GError **err);
+
+gboolean
+kolab_settings_handler_get_bool_field (KolabSettingsHandler *self,
+                                       KolabSettingsHandlerBoolFieldID field_id,
+                                       GError **err);
 
 G_END_DECLS
 
