@@ -48,9 +48,9 @@ static void add_hidden_field_base64 (EContact *e_contact, gchar* field_name, gch
 
 static gint kolab_store_get_sub_id(GList **k_store_sublist, gpointer ptr);
 static void kolab_store_add_id(I_contact *i_contact, gpointer ptr, GList **k_store_sublist,
-		EVCardAttribute *attr);
+                               EVCardAttribute *attr);
 static void kolab_store_add_id_to_field(EContact *e_contact, EContactField ecf, I_contact *i_contact,
-		gpointer ptr, GList **k_store_sublist);
+                                        gpointer ptr, GList **k_store_sublist);
 
 static GList* phone_type_i_to_v(Icontact_phone_type i_phone_type);
 static EContactField address_type_i_to_e(Icontact_address_type i_addr_type);
@@ -186,7 +186,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 		e_contact_photo.data.inlined.mime_type = g_new0(gchar, 100);
 
 		memcpy (e_contact_photo.data.inlined.data, icontact->photo->data,
-				icontact->photo->length);
+		        icontact->photo->length);
 		e_contact_photo.data.inlined.length = icontact->photo->length;
 		e_contact_photo.data.inlined.mime_type = g_strdup (icontact->photo->mime_type);
 		e_contact_photo.data.uri = NULL;
@@ -206,8 +206,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 		EVCardAttributeParam* ph_param = e_vcard_attribute_param_new (EVC_TYPE);
 		e_vcard_attribute_add_param(ph_number, ph_param);
 
-		while (vcard_types != NULL)
-		{
+		while (vcard_types != NULL) {
 			e_vcard_attribute_param_add_value(ph_param, vcard_types->data);			/* set type */
 			vcard_types = vcard_types->next;
 		}
@@ -247,8 +246,8 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 #if 0
 		if (((Email*) list->data)->display_name)
 			addHiddenParamToExistingFieldInEcontact (eContact,
-					email_slot, "display-name",
-					((Email*) list->data)->display_name->str);
+			                                         email_slot, "display-name",
+			                                         ((Email*) list->data)->display_name->str);
 #endif
 		/* log_debug("\nEmail %d \n\tdisplay_name: %s, smtp_address: %s", (i), ((Email*)list->data)->display_name->str, ((Email*)list->data)->smtp_address->str); */
 
@@ -298,7 +297,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 
 	/* *****************************************************************GEO************************************************ */
 	if (icontact->latitude >= -90.0 && icontact->latitude <= 90.0
-		&& icontact->longitude >= -180.0 && icontact->longitude <= 180.0) {
+	    && icontact->longitude >= -180.0 && icontact->longitude <= 180.0) {
 		/* if both degrees are set and their values are valid coordinate values, then set geo */
 		EContactGeo geo;
 		geo.latitude = icontact->latitude;
@@ -308,8 +307,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 
 
 	/* *****************************************************************SET COMMON FIELDS************************************ */
-	if (icontact->common != NULL)
-	{
+	if (icontact->common != NULL) {
 		if (icontact->common->uid != NULL)
 			e_contact_set (e_contact, E_CONTACT_UID, icontact->common->uid->str);
 
@@ -321,7 +319,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 
 
 		if (icontact->common->creation_datetime != NULL
-				&& icontact->common->creation_datetime->date_time != NULL) {
+		    && icontact->common->creation_datetime->date_time != NULL) {
 
 			EVCardAttribute *createdAttribute = NULL;
 			struct tm *ts =	gmtime (icontact->common->creation_datetime->date_time);
@@ -339,8 +337,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 		}
 
 		if (icontact->common->last_modified_datetime != NULL
-				&& icontact->common->last_modified_datetime->date_time != NULL)
-		{
+		    && icontact->common->last_modified_datetime->date_time != NULL) {
 			struct tm *ts = gmtime(icontact->common->last_modified_datetime->date_time);
 			gchar *buf = g_new0(gchar, 21);
 			strftime(buf, 21, "%Y-%m-%dT%H:%M:%SZ", ts);
@@ -378,7 +375,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 			e_contact_set (e_contact, E_CONTACT_BLOG_URL, custom_field->value->str);
 		}
 		else if (strcmp (custom_field->name->str, KLBX_CNT_X_CUSTOM_NAME_ALL) == 0		/* x-custom im */
-				 && i < max_evolution_im) {
+		         && i < max_evolution_im) {
 			EVCardAttribute *im_field = NULL; /* attribute to write */
 
 			/* save just elements that are available in evolution, put other in kolab store */
@@ -405,8 +402,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 			}
 			else if (strcmp (custom_field->app->str, KLBX_CNT_X_CUSTOM_APP_SKYPE) == 0) {	/* skype */
 				im_field = e_vcard_attribute_new(NULL, EVC_X_SKYPE);
-			}
-			else {
+			} else {
 				/* type not found */
 				xmlNodePtr store_node = NULL;
 				store_node = xmlNewNode(NULL, BAD_CAST KLBX_CNT_X_CUSTOM_LIST);
@@ -431,8 +427,7 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 				e_vcard_add_attribute(&e_contact->parent, im_field);
 				i++;
 			}
-		}
-		else {
+		} else {
 			xmlNodePtr store_node = NULL;
 			store_node = xmlNewNode(NULL, BAD_CAST KLBX_CNT_X_CUSTOM_LIST);
 			add_property (store_node, "value", custom_field->value->str);
@@ -457,16 +452,16 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 		list = kolab_store_get_element_list(icontact->common, icontact->common);
 		for (list = g_list_last (list); list != NULL; list = list->prev)
 			add_hidden_field_base64 (e_contact,
-					ICONTACT_KOLAB_STORE,
-					((gchar *) list->data), -1);
+			                         ICONTACT_KOLAB_STORE,
+			                         ((gchar *) list->data), -1);
 
 		/* add kolab store elements with a constant id (name) */
 
 		list = kolab_store_get_element_list(icontact->common, (gpointer) KOLAB_STORE_PTR_CONTACT_NAME);
 		for (list = g_list_last (list); list != NULL; list = list->prev)
 			add_hidden_field_base64 (e_contact,
-					ICONTACT_KOLAB_STORE,
-					((gchar *) list->data), KOLAB_STORE_PTR_CONTACT_NAME);
+			                         ICONTACT_KOLAB_STORE,
+			                         ((gchar *) list->data), KOLAB_STORE_PTR_CONTACT_NAME);
 
 		/* add kolab store elements which are referred by id */
 
@@ -476,8 +471,8 @@ process_contact_i_to_e (EContact* e_contact, I_contact **i_contact)
 			list = kolab_store_get_element_list(icontact->common, k_store_sublist->data);
 			for (; list != NULL; list = list->next)
 				add_hidden_field_base64 (e_contact,
-						ICONTACT_KOLAB_STORE,
-						((gchar *) list->data), i);
+				                         ICONTACT_KOLAB_STORE,
+				                         ((gchar *) list->data), i);
 			i++;
 		}
 	}
@@ -501,17 +496,17 @@ add_binary_field_base64 (EContact *e_contact, Kolab_conv_mail_part *mpart)
 
 	/* Add a encoding parameter to vcard attribute to make it base 64 encoded */
 	e_vcard_attribute_add_param_with_value (bin_attr, e_vcard_attribute_param_new (
-			EVC_ENCODING), "BASE64");
+		         EVC_ENCODING), "BASE64");
 
 	/* Add a mime_type parameter to vcard attribute. */
 	if (mpart->mime_type)
 		e_vcard_attribute_add_param_with_value (bin_attr, e_vcard_attribute_param_new (
-				ICONTACT_KOLAB_STORE_ATTACHMENT_MTYPE), mpart->mime_type);
+			         ICONTACT_KOLAB_STORE_ATTACHMENT_MTYPE), mpart->mime_type);
 
 	/* Add a mime_type parameter to vcard attribute. */
 	if (mpart->name)
 		e_vcard_attribute_add_param_with_value (bin_attr, e_vcard_attribute_param_new (
-				ICONTACT_KOLAB_STORE_ATTACHMENT_NAME), mpart->name);
+			         ICONTACT_KOLAB_STORE_ATTACHMENT_NAME), mpart->name);
 
 	/* Add binary data to the attribute */
 	e_vcard_attribute_add_value_decoded (bin_attr, mpart->data, (gint)mpart->length);
@@ -562,7 +557,7 @@ kolab_store_get_sub_id(GList **k_store_sublist, gpointer ptr)
  */
 static void
 kolab_store_add_id(I_contact *i_contact, gpointer ptr, GList **k_store_sublist,
-		EVCardAttribute *attr)
+                   EVCardAttribute *attr)
 {
 	GList *list = kolab_store_get_element_list(i_contact->common, ptr);
 	if (list != NULL) {
@@ -599,76 +594,58 @@ phone_type_i_to_v(Icontact_phone_type i_phone_type)
 {
 	GList *vcard_types = NULL;
 
-	if (i_phone_type == ICONTACT_PHONE_PRIMARY)	/* one param value */
-	{
+	if (i_phone_type == ICONTACT_PHONE_PRIMARY) {	/* one param value */
 		vcard_types = g_list_append(vcard_types, (gchar*)"PREF");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_ASSISTANT)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_ASSISTANT) {
 		vcard_types = g_list_append(vcard_types, EVC_X_ASSISTANT);
 	}
-	else if (i_phone_type == ICONTACT_PHONE_CALLBACK)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_CALLBACK) {
 		vcard_types = g_list_append(vcard_types, EVC_X_CALLBACK);
 	}
-	else if (i_phone_type == ICONTACT_PHONE_CAR)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_CAR) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"CAR");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_COMPANY)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_COMPANY) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"X-EVOLUTION-COMPANY");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_ISDN)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_ISDN) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"ISDN");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_MOBILE)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_MOBILE) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"CELL");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_PAGER)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_PAGER) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"PAGER");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_RADIO)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_RADIO) {
 		vcard_types = g_list_append(vcard_types, EVC_X_RADIO);
 	}
-	else if (i_phone_type == ICONTACT_PHONE_TELEX)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_TELEX) {
 		vcard_types = g_list_append(vcard_types, EVC_X_TELEX);
 	}
-	else if (i_phone_type == ICONTACT_PHONE_TTYTDD)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_TTYTDD) {
 		vcard_types = g_list_append(vcard_types, EVC_X_TTYTDD);
 	}
-	else if (i_phone_type == ICONTACT_PHONE_OTHER)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_OTHER) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"VOICE");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_HOME_1) /* two param values */
-	{
+	else if (i_phone_type == ICONTACT_PHONE_HOME_1) { /* two param values */
 		vcard_types = g_list_append(vcard_types, (gchar*)"HOME");
 		vcard_types = g_list_append(vcard_types, (gchar*)"VOICE");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_HOME_FAX)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_HOME_FAX) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"HOME");
 		vcard_types = g_list_append(vcard_types, (gchar*)"FAX");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_BUSINESS_1)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_BUSINESS_1) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"WORK");
 		vcard_types = g_list_append(vcard_types, (gchar*)"VOICE");
 	}
-	else if (i_phone_type == ICONTACT_PHONE_BUSINESS_FAX)
-	{
+	else if (i_phone_type == ICONTACT_PHONE_BUSINESS_FAX) {
 		vcard_types = g_list_append(vcard_types, (gchar*)"WORK");
 		vcard_types = g_list_append(vcard_types, (gchar*)"FAX");
-	}
-	else	/* default */
-	{
+	} else	{ /* default */
 		vcard_types = g_list_append(vcard_types, (gchar*)"PREF");
 	}
 
@@ -682,18 +659,12 @@ static EContactField
 address_type_i_to_e(Icontact_address_type i_addr_type)
 {
 	switch (i_addr_type) {
-		case ICONTACT_ADDR_TYPE_HOME:
-			return E_CONTACT_ADDRESS_HOME;
-		case ICONTACT_ADDR_TYPE_BUSINESS:
-			return E_CONTACT_ADDRESS_WORK;
-		case ICONTACT_ADDR_TYPE_OTHER:
-		default:
-			return E_CONTACT_ADDRESS_OTHER;
+	case ICONTACT_ADDR_TYPE_HOME:
+		return E_CONTACT_ADDRESS_HOME;
+	case ICONTACT_ADDR_TYPE_BUSINESS:
+		return E_CONTACT_ADDRESS_WORK;
+	case ICONTACT_ADDR_TYPE_OTHER:
+	default:
+		return E_CONTACT_ADDRESS_OTHER;
 	}
 }
-
-
-
-
-
-
