@@ -237,7 +237,17 @@ free_i_common (I_common **i_common)
 		G_STRING_FREE (ic->categories);
 		free_date_or_datetime (&ic->creation_datetime);
 		free_date_or_datetime (&ic->last_modified_datetime);
-		g_free(ic->vtimezone);
+		/* g_free(ic->vtimezone); */
+		/* FIXME timezone leak fixes in libical0.48 make
+		 *       this one to lead to mem corruption when
+		 *       storing an object (did not happen in 0.44).
+		 *
+		 *       We will need to wait for upstream libical
+		 *       fixes for the memory corruption which
+		 *       are being worked on for an updated 0.48,
+		 *       then return here to see whether we can do
+		 *       better than just not freeing the timezone
+		 */
 
 		g_list_free(ic->kolab_attachment_store); /* no need to free content (must be freed outside of the library) */
 		ic->kolab_attachment_store = NULL;
