@@ -3106,6 +3106,11 @@ validate_kolab_event_505(const I_event *ievent, gint stage)
 {
 	(void)stage;
 
+	/* TEST TEMPORARILY DEACTIVATED */
+	g_debug ("%s()[%u]: TEST TEMPORARILY DEACTIVATED!",
+	         __func__, __LINE__);
+	return;	
+
 	validate_link_attachments(ievent->incidence->common,
 	                          "file:///home/hhelwi/attach_test/penguin.png",
 	                          "file:///home/hhelwi/attach_test/bluefish.png", NULL);
