@@ -33,22 +33,6 @@
 #include <glib.h>
 
 /*----------------------------------------------------------------------------*/
-/* GLib init/shutdown */
-
-void kolab_util_glib_init (void);
-void kolab_util_glib_shutdown (void);
-
-/*----------------------------------------------------------------------------*/
-/* GLib data structures convenience functions */
-
-void kolab_util_glib_ghashtable_gdestroy (gpointer data);
-GHashTable* kolab_util_glib_ghashtable_new_from_str_glist (GList *list);
-
-void kolab_util_glib_glist_free_segment (GList *list);
-void kolab_util_glib_glist_free (GList *list);
-void kolab_util_glib_glist_gdestroy (gpointer data);
-
-gint kolab_util_glib_string_gcompare (gconstpointer a, gconstpointer b);
 
 typedef struct _KolabGConstList KolabGConstList;
 struct _KolabGConstList {
@@ -57,9 +41,43 @@ struct _KolabGConstList {
 	KolabGConstList *prev;
 };
 
-void kolab_util_glib_gconstlist_free (KolabGConstList *list);
-KolabGConstList* kolab_util_glib_gconstlist_prepend (KolabGConstList *list, gconstpointer data);
-KolabGConstList* kolab_util_glib_gconstlist_append (KolabGConstList *list, gconstpointer data);
+/*----------------------------------------------------------------------------*/
+/* GLib init/shutdown */
+
+void kolab_util_glib_init (void);
+void kolab_util_glib_shutdown (void);
+
+/*----------------------------------------------------------------------------*/
+/* GLib data structures convenience functions */
+
+void
+kolab_util_glib_ghashtable_gdestroy (gpointer data);
+
+GHashTable*
+kolab_util_glib_ghashtable_new_from_str_glist (GList *list);
+
+void
+kolab_util_glib_glist_free_segment (GList *list);
+void
+kolab_util_glib_glist_free (GList *list);
+
+void
+kolab_util_glib_glist_gdestroy (gpointer data);
+
+gint
+kolab_util_glib_string_gcompare (gconstpointer a,
+                                 gconstpointer b);
+
+void
+kolab_util_glib_gconstlist_free (KolabGConstList *list);
+
+KolabGConstList*
+kolab_util_glib_gconstlist_prepend (KolabGConstList *list,
+                                    gconstpointer data);
+
+KolabGConstList*
+kolab_util_glib_gconstlist_append (KolabGConstList *list,
+                                   gconstpointer data);
 
 /*----------------------------------------------------------------------------*/
 
